[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)


# Swarms Memory
A collection of memory systems for `swarms` such as Pinecone, ChromaDB, Weaviate

## Install
```bash
$ pip install swarms-memory
```


## Usage

# License
MIT


# Citation
Please cite Swarms in your paper or your project if you found it beneficial in any way! Appreciate you.

```bibtex
@misc{swarms,
  author = {Gomez, Kye},
  title = {{Swarms: The Multi-Agent Collaboration Framework}},
  howpublished = {\url{https://github.com/kyegomez/swarms}},
  year = {2023},
  note = {Accessed: Date}
}
```

